#
# spec file for package python-num2words
#
# Copyright (c) 2022 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%{?!python_module:%define python_module() python-%{**} python3-%{**}}
Name:           python-num2words
Version:        0.5.12
Release:        1.4
Summary:        Modules to convert numbers to words
License:        LGPL-2.1-only
Group:          Development/Languages/Python
URL:            https://github.com/savoirfairelinux/num2words
Source:         https://files.pythonhosted.org/packages/source/n/num2words/num2words-%{version}.tar.gz
BuildRequires:  %{python_module setuptools}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-docopt >= 0.6.2
Requires(post): update-alternatives
Requires(postun):update-alternatives
BuildArch:      noarch
# SECTION test requirements
BuildRequires:  %{python_module delegator.py}
BuildRequires:  %{python_module docopt >= 0.6.2}
BuildRequires:  %{python_module pytest}
# /SECTION
%python_subpackages

%description
num2words is a library that converts numbers like "42" to words like "forty-two".
It supports multiple languages and can even generate ordinal numbers like "forty-second"
(although this last feature is a bit buggy for some languages at the moment).

%prep
%setup -q -n num2words-%{version}

%build
%python_build

%install
%python_install
%python_clone -a %{buildroot}%{_bindir}/num2words
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# test_cli.py has 'python' command hardcoded
%pytest -k "not test_cli" tests

%post
%python_install_alternative num2words

%postun
%python_uninstall_alternative num2words

%files %{python_files}
%doc CHANGES.rst README.rst
%license COPYING
%{python_sitelib}/*
%python_alternative %{_bindir}/num2words

%changelog
* Tue Oct  4 2022 Yogalakshmi Arunachalam <yarunachalam@suse.com>
-Version 0.5.12 -- 2022/08/19
  Support Japanese Reiwa (令和/れいわ) era. (#412)
  Add basic farsi support (#354)
  Added Tajik language support (#406)
  Fix Amharic language support (#465)
  Fix Hebrew pluralize and implement to_currency (#330)
  Add support to translate some currencies in italian language (#434)
  Fix Polish twenties (#345)
  Add uzs for ru and en (#422)
  Added support for Esperanto numbers. (#387)
  [ADD] to ordinal number for Turkish (#468)
  Fix zeroth in Dutch to nulde fixing (#326)
-Version 0.5.11 -- 2022/08/03
  Add KZT and UAH currencies to lang RU (#264)
  Add es_NI currency (#276)
  Update .gitignore to add .eggs/ directory (#280)
  Fix Hebrew support (#289)
  Update test_tr.py to increase coverage (#298)
  Add ordinal 12,345 to ES test suite to increase coverage (#287)
  Add simple tests for lang_DK.py (#286)
  Add testcase for lang_EN.py (#288)
  Add more tests to base.py (#283)
  Fixed misspelling of 21 (cardinal and ordinal number) in IT language (#270)
  Romanian issues 259 (#260)
  Adding Language Support for Telugu / Bug Fix in Kannada (#263)
  Add support of Kazakh language (KZ) (#306)
  Update README.rst (#307)
  Added support for Hungarian language (#310)
  [UPD] Readme file (#363)
  [ADD] num2words: add traslation to spanish of several currencies (#356)
  added swedish language including test cases (#352)
  Remove dupplicated line in lang_PT_BR (#355)
  Fix ordinal_num output for Dutch (NL) (#369)
  Polishordinals (#367)
  [tr] return Turkish 0 ordinal and cardinal (#347)
  Improve Ukrainian support and minor fixes in CZ, KZ, LT, LV, PL, RU, SR languages (#400)
  feat: ci: replace travis by github workflows (#448)
  [ES] Added missing accents ("dieciséis", "dólar", "dólares", "veintiún"), improved currency gender handling, fixed pound cent names (#443)
* Thu May 21 2020 Petr Gajdos <pgajdos@suse.com>
- %%python3_only -> %%python_alternative
* Tue Jun  4 2019 Marketa Calabkova <mcalabkova@suse.com>
- update to 0.5.10
  * Add Kannada language localization (#243)
  * Revert some copyrights changed by mistake (#254)
  * Add indian rupee to the supported currencies (#248)
  * Improve currency functions for German and French (#247)
  * Improve Slovene localization (#246)
  * Improve Spanish localization (#240)
  * Fix typo 'seperator' on source code (#238)
  * Convert string to decimal values (#223)
  * Improve German localization and test coverage (#237)
  * Improve Polish localization (#233)
  * Fix ordinal number for French ending on 1 (#236)
* Fri Apr 12 2019 pgajdos@suse.com
- version update to 0.5.9
  * Fix encoding issue on release 0.5.8 (#229)
  * Improve Polish localization (#228)
  * Add Portuguese (Portugal) localization (#198)
  * Add a command line tool to use num2words
  * Use language iso code for Vietnamese
  * Improve Korean localization (#219)
  * Improve Serbian (Latin) localization (#207)
  * Improve testing setup (#220)
  * Improve German localization (#214) (#222)
  * Improve Romanian localization (#215)
  * Improve Spanish localization (#187) (#200)
  * Improve Russian localization (#211) (#212)
  * Improve French localization (23902ab)
  * Improve Arabic localization (#176)
  * Improve Lithuanian and Latvian localization (#185)
  * Improve Ukrainian localization (#183)
  * Add Finnish localization. (#170)
  * Add Japanese localization. (#171)
  * Add belgian-french localization. (#151)
  * Add Czech localization. (#154)
  * Add Thai localization. (#139)
  * Improve English localization. (#144)
  * Improve Spanish localization. (#167)
  * Improve Italian localization. (#143)
  * Improve documentation. (#155, #145, #174)
* Wed Dec 19 2018 Jan Engelhardt <jengelh@inai.de>
- Trim bias from summary.
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Tue Mar  6 2018 alarrosa@suse.com
- Initial release of python-num2words 0.5.6
